@@ -11,15 +11,14 @@
 #include <KLocalizedString>
 #include <krunner1adaptor.h>
 
-K_PLUGIN_CLASS_WITH_JSON(ActivityRunner, "kactivitymanagerd-plugin-activityrunner.json")
+K_PLUGIN_CLASS(ActivityRunner)
 
-ActivityRunner::ActivityRunner(QObject *parent, const QVariantList &args)
+ActivityRunner::ActivityRunner(QObject *parent)
     : Plugin(parent)
     , m_activitiesService(nullptr)
     , m_keywordi18n(i18nc("KRunner keyword", "activity"))
     , m_keyword(QStringLiteral("activity"))
 {
-    Q_UNUSED(args)
     setName(QStringLiteral("org.kde.ActivityManager.ActivityRunner"));
     new Krunner1Adaptor(this);
     qDBusRegisterMetaType<RemoteMatch>();
@@ -43,8 +42,8 @@ bool ActivityRunner::init(QHash<QString, QObject *> &modules)
 RemoteMatches ActivityRunner::Match(const QString &query)
 {
     Q_ASSERT(m_activitiesService);
-    const auto currentActivity = Plugin::retrieve<QString>(m_activitiesService, "CurrentActivity", "QString");
-    auto activities = Plugin::retrieve<ActivityInfoList>(m_activitiesService, "ListActivitiesWithInformation", "ActivityInfoList");
+    const auto currentActivity = Plugin::retrieve<QString>(m_activitiesService, "CurrentActivity");
+    auto activities = Plugin::retrieve<ActivityInfoList>(m_activitiesService, "ListActivitiesWithInformation");
 
     const QString term = query.trimmed();
     bool list = false;
@@ -59,9 +58,9 @@ RemoteMatches ActivityRunner::Match(const QString &query)
     }
 
     QList<RemoteMatch> matches;
-    for (const ActivityInfo &activityInfo : qAsConst(activities)) {
+    for (const ActivityInfo &activityInfo : std::as_const(activities)) {
         if (currentActivity != activityInfo.id) {
-            auto info = Plugin::retrieve<ActivityInfo>(m_activitiesService, "ActivityInformation", "ActivityInfo", Q_ARG(QString, activityInfo.id));
+            auto info = Plugin::retrieve<ActivityInfo>(m_activitiesService, "ActivityInformation", Q_ARG(QString, activityInfo.id));
             if (list || info.name.startsWith(name, Qt::CaseInsensitive)) {
                 RemoteMatch m;
                 m.id = activityInfo.id;
@@ -90,10 +89,11 @@ RemoteActions ActivityRunner::Actions()
     return {};
 }
 
-void ActivityRunner::Run(const QString &matchId, const QString &actionId)
+void ActivityRunner::Run(const QString &matchId, const QString & /*actionId*/)
 {
-    Q_UNUSED(actionId)
     QMetaObject::invokeMethod(m_activitiesService, "SetCurrentActivity", Q_ARG(QString, matchId));
 }
 
 #include "ActivityRunner.moc"
+
+#include "moc_ActivityRunner.cpp"
